Segment Properties
==================

The ``segmentprops`` module provides tools for reading/writing neuroglancer precomputed `segment properties <https://github.com/google/neuroglancer/blob/master/src/datasource/precomputed/segment_properties.md>`_.

.. automodule:: ngsidekick.segmentprops
   :members:
   :undoc-members:
   :show-inheritance:

